@@ -517,7 +517,7 @@ srl_build_encoder_struct(pTHX_ HV *opt, sv_with_hash *options)
                 if (enc->protocol_version < 3)
                     croak("zstd compression was introduced in protocol version 3 and you are asking for only version %i", (int)enc->protocol_version);
 
-                enc->compress_level = 3; // default compression level
+                enc->compress_level = 3; /* default compression level */
                 my_hv_fetchs(he, val, opt, SRL_ENC_OPT_IDX_COMPRESS_LEVEL);
                 if ( val && SvTRUE(val) ) {
                     IV lvl = SvIV(val);
